﻿# This Script reads SCCM discovered computers from the SCSCM database and creates a csv file with the relevant imprt data for Provance ITAM

# Load SCSMPX Commandlets
import-module scsmpx

# Set Path to store export File
$CSVPath = "C:\transfer\SCCMDiscoveredComputers.csv"

# Define classes to retrieve data
$C_WinCmp = Get-SCClass -Name "Microsoft.windows.Computer"
$C_DplCmp = Get-scclass -Name "Microsoft.SystemCenter.ConfigurationManager.DeployedComputer"
$C_User = Get-SCCLass -Name "System.Domain.User"
$R_CompHasPrimUser = Get-SCRelationship -Name "System.ComputerPrimaryUser"

# Get Discovered Computer Data
$CmpList = @(Get-SCSMClassInstance -Class $C_WinCmp)

# Create empty data array
$CompArr = @()
# Write DiscoveredHardwareData into Array
foreach ($Comp in $CmpList)
    {
        # Get Hardware Chassis Object
        $CompId = $Comp.GetRelatedObjectsWhereTarget($C_DplCmp).EnterpriseManagementObject.Id
        # Get Deployed Computer Object
        $DplComp = Get-SCClassInstance -Class $C_DplCmp -Filter "Id -eq $CompId" -ErrorAction Ignore
        # Get Primary User of the Computer
        $PrimUser = Get-ScsmPxRelatedObject -Source $Comp -RelationshipClassName $R_CompHasPrimUser

        # Put Properties together and write them into PSObject Array
        $data = new-object psobject -Property (
        [Ordered]@{
                ComputerName           =$Comp.PrincipalName;
                IPAddress              =$Comp.IPAddress;
                LastInventoryDate      =$Comp.LastInventoryDate.ToShortDateString()
                HostServerName         =$Comp.HostServerName;
                IsVirtualMachine       =$Comp.IsVirtualMachine;
                VirtualMachineName     =$Comp.VirtualMachineName;
                SerialNumber           =$DplComp.SerialNumber;
                SMBIOSAssetTag         =$DplComp.SMBIOSAssetTag;
                Manufacturer           =$DplComp.Manufacturer;
                Model                  =$DplComp.Model;
                PrimaryUserName        =$PrimUser.UserName;
                PrimaryUserDN          =$PrimUser.DisplayName;
             }
        ) -ErrorAction SilentlyContinue
        $CompArr += $data
        
        Start-Sleep -Milliseconds 50
        
     }
#Create Import CSV File
$CompArr | select -property * | export-csv $CSVPath -Encoding UTF8 -NoTypeInformation

# Unload Modules
Remove-Module scsmpx
